@@ -9,29 +9,23 @@ use parent qw{ Astro::App::Satpass2 };
 
 use Astro::App::Satpass2::Utils qw{ __arguments };
 use Astro::Coord::ECI::Utils 0.059 qw{ rad2deg };
+use Attribute::Handlers;
 use Scalar::Util 1.26 qw{ refaddr };
 
-our $VERSION = '0.046';
+our $VERSION = '0.046_01';
 
 {
     my %operands;
 
-    sub MODIFY_CODE_ATTRIBUTES {
-	my ( $pkg, $code, @args ) = @_;
-	my @rslt;
-	foreach ( @args ) {
-	    if ( m{ \A Operands [(] ( \d+ ) [)] \z }smx ) {
-		$operands{ refaddr( $code ) } = $1;
-	    } else {
-		push @rslt, $_;
-	    }
-	}
-	return $pkg->SUPER::MODIFY_CODE_ATTRIBUTES( $code, @rslt );
+    sub Operands : ATTR(CODE,RAWDATA) {
+	my ( undef, undef, $code, $name, $data ) = @_;
+	$operands{$code}{$name} = 0 + $data;
+	return;
     }
 
     sub operands {
 	my ( $code ) = @_;
-	return $operands{ refaddr( $code ) } || 0;
+	return defined $code ? $operands{$code} || 0 : \%operands;
     }
 }
 
@@ -255,16 +249,16 @@ There are no options.
 
 =head2 test
 
- $output = $satpass2->spaceflight( qw{ -all -effective } );
+ $output = $satpass2->spacetrack( celestrak => 'stations' );
  $output .= $satpass2->dispatch(
      qw{ test 25544 choose else spacetrack retrieve 25544 } );
  
- satpass2> spaceflight -all -full
+ satpass2> spacetrack celestrak stations
  satpass2> test 25544 choose else spacetrack retrieve 25544
  
  # In either of the above cases, the orbital elements come
  # from Space Track only if they could not be retrieved from
- # the NASA's Human Space Flight web site.
+ # Celestrak
 
 This subroutine implements conditional logic. Its arguments are a
 logical expression expressed in reverse Polish notation, and a command
@@ -334,6 +328,7 @@ in the L<TUTORIAL|Astro::App::Satpass2::TUTORIAL>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-App-Satpass2>,
 L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
 electronic mail to the author.
 
