@@ -8,7 +8,7 @@ use warnings;
 use utf8;
 
 use Astro::Coord::ECI::TLE 0.059 qw{ :constants };
-our $VERSION = '0.046';
+our $VERSION = '0.046_01';
 
 my @event_names;
 $event_names[PASS_EVENT_NONE]		= '';
@@ -271,6 +271,7 @@ L<Astro::App::Satpass2::Locale|Astro::App::Satpass2::Locale>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-App-Satpass2>,
 L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
 electronic mail to the author.
 
