@@ -11,7 +11,7 @@ our @ISA = qw{ My::Module::Recommend::Any };
 use Carp;
 use Exporter qw{ import };
 
-our $VERSION = '0.046';
+our $VERSION = '0.046_01';
 
 our @EXPORT_OK = qw{ __all };
 
@@ -29,7 +29,6 @@ sub check {
     return @missing;
 }
 
-
 1;
 
 __END__
@@ -90,6 +89,7 @@ modules in scalar context.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-App-Satpass2>,
 L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
 electronic mail to the author.
 
