@@ -13,7 +13,7 @@ use DateTime;
 use DateTime::TimeZone;
 use POSIX ();
 
-our $VERSION = '0.046';
+our $VERSION = '0.046_01';
 
 # So superclass can ducktype the object that does the real work.
 use constant METHOD_USED => 'format_cldr';
@@ -111,6 +111,7 @@ L<Astro::App::Satpass2::FormatTime::Strftime|Astro::App::Satpass2::FormatTime::S
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-App-Satpass2>,
 L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
 electronic mail to the author.
 
