@@ -11,7 +11,7 @@ use Astro::App::Satpass2::FormatTime::Strftime;
 use Astro::App::Satpass2::Utils qw{ ARRAY_REF @CARP_NOT };
 use POSIX ();
 
-our $VERSION = '0.046';
+our $VERSION = '0.046_01';
 
 sub format_datetime {
     my ( $self, $tplt, $time, $gmt ) = @_;
@@ -94,6 +94,7 @@ L<Astro::App::Satpass2::FormatTime::Strftime|Astro::App::Satpass2::FormatTime::S
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-App-Satpass2>,
 L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
 electronic mail to the author.
 
