@@ -8,7 +8,7 @@ use warnings;
 use Astro::App::Satpass2::FormatValue;
 use Astro::App::Satpass2::Utils qw{ has_method @CARP_NOT };
 
-our $VERSION = '0.046';
+our $VERSION = '0.046_01';
 
 sub new {
     my ( $class, $info ) = @_;
@@ -83,6 +83,7 @@ L<Astro::App::Satpass2::FormatValue|Astro::App::Satpass2::FormatValue>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-App-Satpass2>,
 L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
 electronic mail to the author.
 
