@@ -10,7 +10,7 @@ use parent qw{ Astro::App::Satpass2::Geocode };
 use Astro::App::Satpass2::Utils qw{ instance @CARP_NOT };
 use List::Util ();
 
-our $VERSION = '0.046';
+our $VERSION = '0.046_01';
 
 use constant GEOCODER_CLASS => 'Geo::Coder::OSM';
 
@@ -136,6 +136,7 @@ lifting.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-App-Satpass2>,
 L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
 electronic mail to the author.
 
