@@ -11,7 +11,7 @@ use Astro::Coord::ECI::TLE 0.059 qw{ :constants };
 use Astro::App::Satpass2::Utils qw{ @CARP_NOT };
 use Scalar::Util ();
 
-our $VERSION = '0.046';
+our $VERSION = '0.046_01';
 
 my @event_names;
 $event_names[PASS_EVENT_NONE]		= '';
@@ -145,7 +145,6 @@ EOD
     [%= data.longitude( arg ) %] [% data.altitude( arg ) -%]
 EOD
 
-
 	location	=> <<'EOD',
 [% UNLESS data %]
     [%- SET data = sp.location( arg ) %]
@@ -640,6 +639,7 @@ L<Astro::App::Satpass2::Locale|Astro::App::Satpass2::Locale>
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-App-Satpass2>,
 L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
 electronic mail to the author.
 
