@@ -9,7 +9,7 @@ use parent qw{ Astro::App::Satpass2::ParseTime };
 
 use Astro::App::Satpass2::Utils qw{ CODE_REF HASH_REF @CARP_NOT };
 
-our $VERSION = '0.046';
+our $VERSION = '0.046_01';
 
 use constant DUMMY	=> 'DUMMY';
 
@@ -219,6 +219,7 @@ L<parse_time_absolute()|Astro::App::Satpass2::ParseTime/parse_time_absolute>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-App-Satpass2>,
 L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
 electronic mail to the author.
 
