@@ -9,11 +9,10 @@ use parent qw{ Astro::App::Satpass2::ParseTime::Date::Manip };
 
 use Astro::App::Satpass2::Utils qw{ load_package @CARP_NOT };
 
-our $VERSION = '0.046';
+our $VERSION = '0.046_01';
 
 my $invalid;
 
-
 BEGIN {
     eval {
 	load_package( 'Date::Manip' )
@@ -174,6 +173,7 @@ zone.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Astro-App-Satpass2>,
 L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
 electronic mail to the author.
 
